---
name: 'Bug report: Cubeviz'
about: Bug report for Cubeviz
title: "[BUG] Cubeviz:"
labels: bug, cubeviz
assignees: ''

---

<!-- This comments are hidden when you submit the issue,
so you do not need to remove them! -->

<!-- Please have a search on our GitHub repository to see if a similar
issue has already been posted.
If a similar issue is closed, have a quick look to see if you are satisfied
by the resolution.
If not please go ahead and open an issue! -->

<!-- This is a public repository, please scrub out sensitive information! -->

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Desktop (please complete the following information):**
 - OS: [e.g. iOS]
 - Browser: [e.g. chrome 88, safari 22]
 - Jupyter: [run "jupyter --version"]

**Package versions (please complete the following information):**
<!-- Even if you do not think this is necessary, it is useful information for the maintainers.
Please run the following snippet and paste the output below:
import platform; print(platform.platform())
import sys; print("Python", sys.version)
import numpy; print("Numpy", numpy.__version__)
import astropy; print("astropy", astropy.__version__)
import matplotlib; print("matplotlib", matplotlib.__version__)
import scipy; print("scipy", scipy.__version__)
import skimage; print("scikit-image", skimage.__version__)
import asdf; print("asdf", asdf.__version__)
import gwcs; print("gwcs", gwcs.__version__)
import regions; print("regions", regions.__version__)
import specutils; print("specutils", specutils.__version__)
import photutils; print("photutils", photutils.__version__)
import yaml; print("pyyaml", yaml.__version__)
import click; print("click", click.__version__)
import asteval; print("asteval", asteval.__version__)
import idna; print("idna", idna.__version__)
import traitlets; print("traitlets", traitlets.__version__)
import bqplot; print("bqplot", bqplot.__version__)
import bqplot_image_gl; print("bqplot-image-gl", bqplot_image_gl.__version__)
import glue; print("glue-core", glue.__version__)
import glue_jupyter; print("glue-jupyter", glue_jupyter.__version__)
import glue_astronomy; print("glue-astronomy", glue_astronomy.__version__)
import echo; print("echo", echo.__version__)
import ipyvue; print("ipyvue", ipyvue.__version__)
import ipyvuetify; print("ipyvuetify", ipyvuetify.__version__)
import ipysplitpanes; print("ipysplitpanes", ipysplitpanes.__version__)
import ipygoldenlayout; print("ipygoldenlayout", ipygoldenlayout.__version__)
import jinja2; print("Jinja2", jinja2.__version__)
import voila; print("voila", voila.__version__)
import vispy; print("vispy", vispy.__version__)
import sidecar; print("sidecar", sidecar.__version__)
import jdaviz; print("Jdaviz", jdaviz.__version__)
-->


**Additional context (e.g. data files)**
Add any other context about the problem here.
